Direct contributions to the code base:

- `José Vinícius de Miranda Cardoso <https://github.com/mirca>`_
- `Geert Barentsen <https://github.com/barentsen>`_
- `Christina Hedges <https://github.com/christinahedges>`_
- `Michael Gully-Santiago <https://github.com/gully>`_
- `Thomas Barclay <https://github.com/mrtommyb>`_

Comments, corrections & suggestions:

- `Ann Marie Cody <https://github.com/amcody>`_
- `Jessie Dotson <https://github.com/jessie-dotson>`_
- `Clare Brasseur <https://github.com/ceb8>`_
- `Elisa Quintana <https://github.com/elisaquintana>`_
- `Doug Caldwell <https://github.com/dacmess>`_
- `Daniel Foreman-Mackey <https://github.com/dfm>`_
- Jeff Van Cleve
- Ashley Villar
- TJ Jaffe
